@@ -532,6 +532,10 @@ def genconfig(devicename):
             # we need to deep copy the profiles as we may remove things from
             # them due to the 'profiles-exclude' option
 
+            if debug:
+                print("debug: merging device profile: %s" % profile,
+                      file=sys.stderr)
+
             deepmerge(
                 profiles_merged,
                 deepcopy(inventory["device-profiles"][profile]))
@@ -541,6 +545,10 @@ def genconfig(devicename):
         # these from the merged profile we just assembled
 
         if "profiles-exclude" in inventory["devices"][devicename]:
+            if debug:
+                print("debug: excluding items from device profile",
+                      file=sys.stderr)
+
             deepremoveitems(profiles_merged, device["profiles-exclude"])
 
 
@@ -550,6 +558,9 @@ def genconfig(devicename):
         #
         # we then replace the device definition with the merged one
 
+        if debug:
+            print("debug: merging into device", file=sys.stderr)
+
         deepmerge(profiles_merged, deepcopy(device))
 
         device = profiles_merged
